@@ -3,8 +3,9 @@ Main interface for swf service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.swf import (
+    from mypy_boto3_swf import (
         Client,
         GetWorkflowExecutionHistoryPaginator,
         ListActivityTypesPaginator,
@@ -14,7 +15,7 @@ Usage::
         ListWorkflowTypesPaginator,
         PollForDecisionTaskPaginator,
         SWFClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -28,8 +29,9 @@ Usage::
     list_open_workflow_executions_paginator: ListOpenWorkflowExecutionsPaginator = client.get_paginator("list_open_workflow_executions")
     list_workflow_types_paginator: ListWorkflowTypesPaginator = client.get_paginator("list_workflow_types")
     poll_for_decision_task_paginator: PollForDecisionTaskPaginator = client.get_paginator("poll_for_decision_task")
+    ```
 """
-from mypy_boto3_swf.client import SWFClient as Client, SWFClient
+from mypy_boto3_swf.client import SWFClient, SWFClient as Client
 from mypy_boto3_swf.paginator import (
     GetWorkflowExecutionHistoryPaginator,
     ListActivityTypesPaginator,
