@@ -3,8 +3,11 @@ Main interface for swf service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.swf import (
+
+    from mypy_boto3_swf import SWFClient
+    from mypy_boto3_swf import (
         GetWorkflowExecutionHistoryPaginator,
         ListActivityTypesPaginator,
         ListClosedWorkflowExecutionsPaginator,
@@ -23,6 +26,7 @@ Usage::
     list_open_workflow_executions_paginator: ListOpenWorkflowExecutionsPaginator = client.get_paginator("list_open_workflow_executions")
     list_workflow_types_paginator: ListWorkflowTypesPaginator = client.get_paginator("list_workflow_types")
     poll_for_decision_task_paginator: PollForDecisionTaskPaginator = client.get_paginator("poll_for_decision_task")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
@@ -64,24 +68,24 @@ __all__ = (
 
 class GetWorkflowExecutionHistoryPaginator(Boto3Paginator):
     """
-    [Paginator.GetWorkflowExecutionHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)
+    [Paginator.GetWorkflowExecutionHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)
     """
 
     def paginate(
         self,
         domain: str,
-        execution: WorkflowExecutionTypeDef,
+        execution: "WorkflowExecutionTypeDef",
         reverseOrder: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[HistoryTypeDef]:
         """
-        [GetWorkflowExecutionHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory.paginate)
+        [GetWorkflowExecutionHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory.paginate)
         """
 
 
 class ListActivityTypesPaginator(Boto3Paginator):
     """
-    [Paginator.ListActivityTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.ListActivityTypes)
+    [Paginator.ListActivityTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.ListActivityTypes)
     """
 
     def paginate(
@@ -93,13 +97,13 @@ class ListActivityTypesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ActivityTypeInfosTypeDef]:
         """
-        [ListActivityTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.ListActivityTypes.paginate)
+        [ListActivityTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.ListActivityTypes.paginate)
         """
 
 
 class ListClosedWorkflowExecutionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListClosedWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)
+    [Paginator.ListClosedWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)
     """
 
     def paginate(
@@ -115,13 +119,13 @@ class ListClosedWorkflowExecutionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[WorkflowExecutionInfosTypeDef]:
         """
-        [ListClosedWorkflowExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions.paginate)
+        [ListClosedWorkflowExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions.paginate)
         """
 
 
 class ListDomainsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.ListDomains)
+    [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.ListDomains)
     """
 
     def paginate(
@@ -131,13 +135,13 @@ class ListDomainsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DomainInfosTypeDef]:
         """
-        [ListDomains.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.ListDomains.paginate)
+        [ListDomains.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.ListDomains.paginate)
         """
 
 
 class ListOpenWorkflowExecutionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListOpenWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)
+    [Paginator.ListOpenWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)
     """
 
     def paginate(
@@ -151,13 +155,13 @@ class ListOpenWorkflowExecutionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[WorkflowExecutionInfosTypeDef]:
         """
-        [ListOpenWorkflowExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions.paginate)
+        [ListOpenWorkflowExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions.paginate)
         """
 
 
 class ListWorkflowTypesPaginator(Boto3Paginator):
     """
-    [Paginator.ListWorkflowTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)
+    [Paginator.ListWorkflowTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)
     """
 
     def paginate(
@@ -169,23 +173,23 @@ class ListWorkflowTypesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[WorkflowTypeInfosTypeDef]:
         """
-        [ListWorkflowTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes.paginate)
+        [ListWorkflowTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes.paginate)
         """
 
 
 class PollForDecisionTaskPaginator(Boto3Paginator):
     """
-    [Paginator.PollForDecisionTask documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)
+    [Paginator.PollForDecisionTask documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)
     """
 
     def paginate(
         self,
         domain: str,
-        taskList: TaskListTypeDef,
+        taskList: "TaskListTypeDef",
         identity: str = None,
         reverseOrder: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DecisionTaskTypeDef]:
         """
-        [PollForDecisionTask.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.9/reference/services/swf.html#SWF.Paginator.PollForDecisionTask.paginate)
+        [PollForDecisionTask.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/swf.html#SWF.Paginator.PollForDecisionTask.paginate)
         """
